@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -13,9 +13,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -38,39 +39,39 @@
 #include <sys/file.h>
 #include <pwd.h>
 #include <grp.h>
-#include <radius.h>
+#include <radlib.h>
 
 /* Memory allocation interface */
 
-VALUE_PAIR *
-avp_alloc()
+grad_avp_t *
+grad_avp_alloc()
 {
-        return emalloc(sizeof(VALUE_PAIR));
+        return grad_emalloc(sizeof(grad_avp_t));
 }
 
 void
-avp_free(VALUE_PAIR *p)
+grad_avp_free(grad_avp_t *p)
 {
         if (!p)
                 return;
-        if (p->type == TYPE_STRING || p->eval_type != eval_const) 
-                efree(p->avp_strvalue);
-        efree(p);
+        if (p->type == GRAD_TYPE_STRING || p->eval_type != grad_eval_const) 
+                grad_free(p->avp_strvalue);
+        grad_free(p);
 }
 
 /* A/V pair functions */
 
 /* Create a copy of a pair */
-VALUE_PAIR *
-avp_dup(VALUE_PAIR *vp)
+grad_avp_t *
+grad_avp_dup(grad_avp_t *vp)
 {
-        VALUE_PAIR *ret = avp_alloc();
+        grad_avp_t *ret = grad_avp_alloc();
 
-        memcpy(ret, vp, sizeof(VALUE_PAIR));
+        memcpy(ret, vp, sizeof(grad_avp_t));
         ret->next = NULL;
-        if (ret->type == TYPE_STRING || ret->eval_type != eval_const) {
+        if (ret->type == GRAD_TYPE_STRING || ret->eval_type != grad_eval_const) {
 		ret->avp_strlength = vp->avp_strlength;
-                ret->avp_strvalue = emalloc(ret->avp_strlength+1);
+                ret->avp_strvalue = grad_emalloc(ret->avp_strlength+1);
 		memcpy(ret->avp_strvalue, vp->avp_strvalue,
 		       ret->avp_strlength);
 		ret->avp_strvalue[ret->avp_strlength] = 0;
@@ -79,19 +80,20 @@ avp_dup(VALUE_PAIR *vp)
 }
 
 /* Create a pair with given attribute */
-VALUE_PAIR *
-avp_create(int attr)
+grad_avp_t *
+grad_avp_create(int attr)
 {
-        VALUE_PAIR *pair;
-        DICT_ATTR  *dict;
+        grad_avp_t *pair;
+        grad_dict_attr_t  *dict;
 
-        dict = attr_number_to_dict(attr);
+        dict = grad_attr_number_to_dict(attr);
         if (!dict) {
-                radlog(L_ERR, _("make_pair(): attribute %d not found in dictionary"),
-                       attr);
+                grad_log(L_ERR,
+                         _("make_pair(): attribute %d not found in dictionary"),
+                         attr);
                 return NULL;
         }
-        pair = avp_alloc();
+        pair = grad_avp_alloc();
         pair->name = dict->name;
         pair->attribute = attr;
         pair->type = dict->type;
@@ -99,45 +101,45 @@ avp_create(int attr)
 	return pair;
 }
 
-VALUE_PAIR *
-avp_create_integer(int attr, UINT4 value)
+grad_avp_t *
+grad_avp_create_integer(int attr, grad_uint32_t value)
 {
-	VALUE_PAIR *pair = avp_create(attr);
+	grad_avp_t *pair = grad_avp_create(attr);
 
 	if (pair) 
 		pair->avp_lvalue = value;
 	return pair;
 }
 
-VALUE_PAIR *
-avp_create_string(int attr, char *value)
+grad_avp_t *
+grad_avp_create_string(int attr, char *value)
 {
-	VALUE_PAIR *pair = avp_create(attr);
+	grad_avp_t *pair = grad_avp_create(attr);
 	if (pair) {
-		pair->avp_strvalue = estrdup(value);
+		pair->avp_strvalue = grad_estrdup(value);
                 pair->avp_strlength = strlen(value);
 	}
 	return pair;
 }
 
-VALUE_PAIR *
-avp_create_binary(int attr, int length, u_char *value)
+grad_avp_t *
+grad_avp_create_binary(int attr, int length, u_char *value)
 {
-	VALUE_PAIR *pair = avp_create(attr);
+	grad_avp_t *pair = grad_avp_create(attr);
 	if (pair) {
                 pair->avp_strlength = length;
-                pair->avp_strvalue = emalloc(length + 1);
+                pair->avp_strvalue = grad_emalloc(length + 1);
 		memcpy(pair->avp_strvalue, value, length);
 		pair->avp_strvalue[length] = 0;
 	}
 	return pair;
 }
 
-/* Add a pair to the end of a VALUE_PAIR list. */
-VALUE_PAIR *
-avp_move(VALUE_PAIR **first, VALUE_PAIR *new)
+/* Add a pair to the end of a grad_avp_t list. */
+grad_avp_t *
+grad_avp_move(grad_avp_t **first, grad_avp_t *new)
 {
-        VALUE_PAIR *pair, *prev = NULL;
+        grad_avp_t *pair, *prev = NULL;
 
         if (*first == NULL) {
                 new->next = NULL;
@@ -145,8 +147,8 @@ avp_move(VALUE_PAIR **first, VALUE_PAIR *new)
                 return 0;
         }
 
-        switch (ADDITIVITY(new->prop)) {
-        case AP_ADD_NONE:
+        switch (GRAD_GET_ADDITIVITY(new->prop)) {
+        case GRAD_AP_ADD_NONE:
                 for (pair = *first; pair; prev = pair, pair = pair->next)
                         if (pair->attribute == new->attribute)
                                 return new;
@@ -154,26 +156,26 @@ avp_move(VALUE_PAIR **first, VALUE_PAIR *new)
                 new->next = NULL;
                 return NULL;
 
-        case AP_ADD_REPLACE:
+        case GRAD_AP_ADD_REPLACE:
                 if ((*first)->attribute == new->attribute) {
                         prev = *first;
                         new->next = prev->next;
                         *first = new;
-                        avp_free(prev);
+                        grad_avp_free(prev);
                         return NULL;
                 }
                 for (pair = *first; pair; prev = pair, pair = pair->next)
                         if (pair->attribute == new->attribute) {
                                 new->next = pair->next;
                                 prev->next = new;
-                                avp_free(pair);
+                                grad_avp_free(pair);
                                 return NULL;
                         }
                 new->next = NULL;
                 prev->next = new;
                 return NULL;
 
-        case AP_ADD_APPEND:
+        case GRAD_AP_ADD_APPEND:
                 for (pair = *first; pair->next; pair = pair->next)
                         ;
                 new->next = NULL;
@@ -184,7 +186,7 @@ avp_move(VALUE_PAIR **first, VALUE_PAIR *new)
 }
 
 int
-avp_cmp(VALUE_PAIR *a, VALUE_PAIR *b)
+grad_avp_cmp(grad_avp_t *a, grad_avp_t *b)
 {
 	int rc = 1;
 	
@@ -192,7 +194,7 @@ avp_cmp(VALUE_PAIR *a, VALUE_PAIR *b)
 		return 1;
 	
 	switch (a->type) {
-	case TYPE_STRING:
+	case GRAD_TYPE_STRING:
 		if (a->avp_strlength != b->avp_strlength)
 			rc = 1;
 		else
@@ -200,8 +202,8 @@ avp_cmp(VALUE_PAIR *a, VALUE_PAIR *b)
                                     a->avp_strlength);
 		break;
 
-	case TYPE_INTEGER:
-	case TYPE_IPADDR:
+	case GRAD_TYPE_INTEGER:
+	case GRAD_TYPE_IPADDR:
 		rc = a->avp_lvalue != b->avp_lvalue;
 		break;
 	}
@@ -209,11 +211,11 @@ avp_cmp(VALUE_PAIR *a, VALUE_PAIR *b)
 }
 
 int
-avp_null_string_p(VALUE_PAIR *pair)
+grad_avp_null_string_p(grad_avp_t *pair)
 {
 	if (!pair)
 		return 1;
-	if (pair->type != TYPE_STRING)
+	if (pair->type != GRAD_TYPE_STRING)
 		return 1;
 	return strlen(pair->avp_strvalue) == 0;
 }
@@ -223,13 +225,13 @@ avp_null_string_p(VALUE_PAIR *pair)
 /* Release the memory used by a list of attribute-value pairs.
  */
 void 
-avl_free(VALUE_PAIR *pair)
+grad_avl_free(grad_avp_t *pair)
 {
-        VALUE_PAIR *next;
+        grad_avp_t *next;
 
         while (pair != NULL) {
                 next = pair->next;
-                avp_free(pair);
+                grad_avp_free(pair);
                 pair = next;
         }
 }
@@ -237,8 +239,8 @@ avl_free(VALUE_PAIR *pair)
 
 /* Find the pair with the matching attribute
  */
-VALUE_PAIR * 
-avl_find(VALUE_PAIR *first, int attr)
+grad_avp_t * 
+grad_avl_find(grad_avp_t *first, int attr)
 {
         while (first && first->attribute != attr)
                 first = first->next;
@@ -246,8 +248,8 @@ avl_find(VALUE_PAIR *first, int attr)
 }
 
 /* Find nth occurrence of a pair with the matching attribute. */
-VALUE_PAIR * 
-avl_find_n(VALUE_PAIR *first, int attr,	int n)
+grad_avp_t * 
+grad_avl_find_n(grad_avp_t *first, int attr,	int n)
 {
 	for ( ; first; first = first->next) {
 		if (first->attribute == attr && n-- == 0)
@@ -259,9 +261,9 @@ avl_find_n(VALUE_PAIR *first, int attr,	int n)
 /* Delete the pairs with the matching attribute
  */
 void 
-avl_delete(VALUE_PAIR **first, int attr)
+grad_avl_delete(grad_avp_t **first, int attr)
 {
-        VALUE_PAIR *pair, *next, *last = NULL;
+        grad_avp_t *pair, *next, *last = NULL;
 
         for (pair = *first; pair; pair = next) {
                 next = pair->next;
@@ -270,7 +272,7 @@ avl_delete(VALUE_PAIR **first, int attr)
                                 last->next = next;
                         else
                                 *first = next;
-                        avp_free(pair);
+                        grad_avp_free(pair);
                 } else
                         last = pair;
         }
@@ -278,9 +280,9 @@ avl_delete(VALUE_PAIR **first, int attr)
 
 /* Delete Nth pair with the matching attribute */
 void 
-avl_delete_n(VALUE_PAIR **first, int attr, int n)
+grad_avl_delete_n(grad_avp_t **first, int attr, int n)
 {
-	VALUE_PAIR *pair, *next, *last = NULL;
+	grad_avp_t *pair, *next, *last = NULL;
 
 	for (pair = *first; pair; pair = next) {
 		next = pair->next;
@@ -289,7 +291,7 @@ avl_delete_n(VALUE_PAIR **first, int attr, int n)
 				last->next = next;
 			else
 				*first = next;
-			avp_free(pair);
+			grad_avp_free(pair);
 			break;
 		} else
 			last = pair;
@@ -299,11 +301,13 @@ avl_delete_n(VALUE_PAIR **first, int attr, int n)
 
 /* Move all attributes of a given type from one list to another */
 void
-avl_move_pairs(VALUE_PAIR **to, VALUE_PAIR **from, int (*fun)(),
-	       void *closure)
+grad_avl_move_pairs(grad_avp_t **to,
+		    grad_avp_t **from,
+		    int (*fun)(void *, grad_avp_t *),
+		    void *closure)
 {
-        VALUE_PAIR *to_tail, *i, *next;
-        VALUE_PAIR *iprev = NULL;
+        grad_avp_t *to_tail, *i, *next;
+        grad_avp_t *iprev = NULL;
 
         /*
          *      Find the last pair in the "to" list and put it in "to_tail".
@@ -344,24 +348,25 @@ avl_move_pairs(VALUE_PAIR **to, VALUE_PAIR **from, int (*fun)(),
 }
 
 static int
-cmp_attr(int *valp, VALUE_PAIR *pair)
+cmp_attr(void *data, grad_avp_t *pair)
 {
+	int *valp = data; 
         return *valp == pair->attribute;
 }
 
 /* Move all attributes of a given type from one list to another */
 void
-avl_move_attr(VALUE_PAIR **to, VALUE_PAIR **from, int attr)
+grad_avl_move_attr(grad_avp_t **to, grad_avp_t **from, int attr)
 {
-        avl_move_pairs(to, from, cmp_attr, &attr);
+        grad_avl_move_pairs(to, from, cmp_attr, &attr);
 }
 
 /* Move attributes from one list to the other honoring their additivity 
  */
 void
-avl_merge(VALUE_PAIR **dst_ptr, VALUE_PAIR **src_ptr)
+grad_avl_merge(grad_avp_t **dst_ptr, grad_avp_t **src_ptr)
 {
-        VALUE_PAIR *src, *next, *src_head, *src_tail;
+        grad_avp_t *src, *next, *src_head, *src_tail;
 
         if (*dst_ptr == NULL) {
                 *dst_ptr = *src_ptr;
@@ -373,7 +378,7 @@ avl_merge(VALUE_PAIR **dst_ptr, VALUE_PAIR **src_ptr)
         src = *src_ptr;
         while (src) {
                 next = src->next;
-                src = avp_move(dst_ptr, src);
+                src = grad_avp_move(dst_ptr, src);
                 if (src) {
                         if (src_tail)
                                 src_tail->next = src;
@@ -388,9 +393,9 @@ avl_merge(VALUE_PAIR **dst_ptr, VALUE_PAIR **src_ptr)
 
 /* Append the list `new' to the end of the list `*first' */
 void
-avl_add_list(VALUE_PAIR **first, VALUE_PAIR *new)
+grad_avl_add_list(grad_avp_t **first, grad_avp_t *new)
 {
-        VALUE_PAIR *pair;
+        grad_avp_t *pair;
         
         if (*first == NULL) {
                 *first = new;
@@ -403,28 +408,28 @@ avl_add_list(VALUE_PAIR **first, VALUE_PAIR *new)
 
 /* Add a single pair to the list */
 void
-avl_add_pair(VALUE_PAIR **first, VALUE_PAIR *new)
+grad_avl_add_pair(grad_avp_t **first, grad_avp_t *new)
 {
         if (!new)
                 return;
         new->next = NULL;
-        avl_add_list(first, new);
+        grad_avl_add_list(first, new);
 }
 
 
 /* Create a copy of a pair list. */
-VALUE_PAIR *
-avl_dup(VALUE_PAIR *from)
+grad_avp_t *
+grad_avl_dup(grad_avp_t *from)
 {
-        VALUE_PAIR *first = NULL;
-        VALUE_PAIR *last = NULL;
-        VALUE_PAIR *temp;
+        grad_avp_t *first = NULL;
+        grad_avp_t *last = NULL;
+        grad_avp_t *temp;
 
         for ( ; from; from = from->next) {
-                temp = avp_alloc();
-                memcpy(temp, from, sizeof(VALUE_PAIR));
-                if (temp->type == TYPE_STRING || temp->eval_type != eval_const) {
-			char *p = emalloc(temp->avp_strlength+1);
+                temp = grad_avp_alloc();
+                memcpy(temp, from, sizeof(grad_avp_t));
+                if (temp->type == GRAD_TYPE_STRING || temp->eval_type != grad_eval_const) {
+			char *p = grad_emalloc(temp->avp_strlength+1);
 			memcpy(p, temp->avp_strvalue, temp->avp_strlength);
 			p[temp->avp_strlength] = 0;
 			temp->avp_strvalue = p;
@@ -442,27 +447,27 @@ avl_dup(VALUE_PAIR *from)
 
 /* write a pairlist to the file */
 void
-avl_fprint(FILE *fp, char *prefix, int typeflag, VALUE_PAIR *avl)
+grad_avl_fprint(FILE *fp, char *prefix, int typeflag, grad_avp_t *avl)
 {
         char *save;
 	if (!prefix)
 		prefix = "";
         for (;avl; avl = avl->next) {
                 fprintf(fp, "%s%s\n", prefix,
-			format_pair(avl, typeflag, &save));
+			grad_format_pair(avl, typeflag, &save));
                 free(save);
         }
 }
 
 int
-avl_cmp(VALUE_PAIR *a, VALUE_PAIR *b, int prop)
+grad_avl_cmp(grad_avp_t *a, grad_avp_t *b, int prop)
 {
 	int cmp_count = 0;
 	
 	for (; a; a = a->next) {
 		if (a->prop & prop) {
-			VALUE_PAIR *p = avl_find(b, a->attribute);
-			if (!p || avp_cmp(a, p))
+			grad_avp_t *p = grad_avl_find(b, a->attribute);
+			if (!p || grad_avp_cmp(a, p))
 				return 1;
 			cmp_count++;
 		}
