@@ -1,5 +1,6 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -34,7 +35,7 @@
 #include <errno.h>
 #include <ctype.h>
 
-#include <common.h>
+#include <radlib.h>
 
 void
 grad_client_random_authenticator(char *authenticator)
@@ -109,8 +110,8 @@ grad_client_message_id(grad_server_t *server)
 }
 	
 grad_request_t *
-grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret, char *authenticator,
-	     char *buffer, int length)
+grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret,
+		 char *authenticator, char *buffer, int length)
 {
         grad_packet_header_t *auth;
         int totallen;
@@ -136,7 +137,7 @@ grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret, char *authe
         memcpy(buffer + length, secret, secretlen);
         grad_md5_calc(calc_digest, (unsigned char *)auth, length + secretlen);
         
-	debug(1, ("received %s", grad_request_code_to_name(auth->code)));
+	GRAD_DEBUG1(1, "received %s", grad_request_code_to_name(auth->code));
         if (memcmp(reply_digest, calc_digest, GRAD_AUTHENTICATOR_LENGTH) != 0) {
                 grad_log(L_WARN, _("Received invalid reply digest from server"));
         }
@@ -244,8 +245,7 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                 return NULL;
         }
 
-	debug(1,
-	      ("sending %s", grad_request_code_to_name(code)));
+	GRAD_DEBUG1(1, "sending %s", grad_request_code_to_name(code));
 	recv_buf = grad_emalloc(config->buffer_size);
         itr = grad_iterator_create(config->servers);
         server = grad_iterator_first(itr);
@@ -261,11 +261,9 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                 if (server->port[port_type] <= 0)
                         continue;
                 
-                if (debug_on(10)) {
-                        grad_log(L_DEBUG, "server %s:%d",
+                GRAD_DEBUG2(10, "server %s:%d",
                                  grad_ip_iptostr(server->addr, ipbuf),
                                  server->port[port_type]);
-                }
 
                 if (authid && (flags & RADCLT_AUTHENTICATOR))
 			memcpy(authenticator, authvec, sizeof authenticator);
@@ -317,8 +315,8 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                         if (select(sockfd+1, &readfds, NULL, NULL, &tm) < 0) {
                                 if (errno == EINTR) {
                                         i--;
-					debug(20,
-					      ("select interrupted. retrying."));
+					GRAD_DEBUG(20,
+					      "select interrupted. retrying.");
                                         continue;
                                 }
                                 grad_log(L_NOTICE, _("select() interrupted"));
@@ -347,15 +345,15 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                                 
                                 break;
                         }
-			debug(10,("no response. retrying."));
+			GRAD_DEBUG(10,"no response. retrying.");
                 }
 		
 		grad_free(pdu);
 		
                 if (!req)
-                        debug(10,("no reply from %s:%d",
-				  grad_ip_iptostr(server->addr, ipbuf),
-				  server->port[port_type]));
+                        GRAD_DEBUG2(10,"no reply from %s:%d",
+				    grad_ip_iptostr(server->addr, ipbuf),
+				    server->port[port_type]);
 		
         } while (!req && (server = grad_iterator_next(itr)) != NULL);
 	grad_iterator_destroy(&itr);
