@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2005,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -13,9 +13,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -34,7 +35,7 @@
 #include <argp.h>
 #include <common.h>
 
-const char *argp_program_bug_address = "<bug-gnu-radius@gnu.org>";
+const char *argp_program_bug_address = "<" PACKAGE_BUGREPORT ">";
 
 static struct argp_option rad_common_argp_option[] = {
         {"directory", 'd', N_("DIR"), 0,
@@ -46,7 +47,7 @@ static struct argp_option rad_common_argp_option[] = {
 static error_t rad_common_argp_parser (int key, char *arg,
                                        struct argp_state *state);
 
-struct argp rad_common_argp = {
+struct argp grad_common_argp = {
         rad_common_argp_option,
         rad_common_argp_parser,
         NULL,
@@ -56,11 +57,21 @@ struct argp rad_common_argp = {
         NULL
 };
 
-struct argp_child rad_common_argp_child[] = {
-        { &rad_common_argp, 0, N_("Common options"), 1 },
+struct argp_child grad_common_argp_child[] = {
+        { &grad_common_argp, 0, N_("Common options"), 1 },
 	{ NULL },
 };
 
+char *
+__argp_base_name(const char *arg)
+{
+	const char *p = strrchr(arg, '/');
+	if (!p)
+		p = arg;
+	else
+		p++;
+	return (char*)p;
+}
 
 static char license_text[] = N_(
     "   This program is free software; you can redistribute it and/or modify\n"
@@ -75,7 +86,9 @@ static char license_text[] = N_(
     "\n"
     "   You should have received a copy of the GNU General Public License\n"
     "   along with GNU Radius; if not, write to the Free Software Foundation,\n"
-    "   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n");
+    "   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.\n"
+    "\n"
+);
 
 
 static error_t 
@@ -83,7 +96,7 @@ rad_common_argp_parser(int key, char *arg, struct argp_state *state)
 {
         switch (key) {
         case 'd':
-                radius_dir = arg;
+                grad_config_dir = arg;
                 break;
 
         case 'L':
