@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2002,2003,2004,2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -34,7 +34,7 @@
 #include <time.h>
 #include <ctype.h>
 
-#include <common.h>
+#include <radlib.h>
 
 /* Build and send a reply to the incoming request.
    Input: fd          -- Socket descriptor.
@@ -70,11 +70,11 @@ grad_server_send_reply(int fd, grad_request_t *radreq,
 			 grad_ip_iptostr(radreq->ipaddr, NULL),
 			 grad_nas_request_to_name(radreq, buf, sizeof buf));
 #else		
-                debug(1, ("Sending %s of id %d to %s (nas %s)",
+                GRAD_DEBUG4(1, "Sending %s of id %d to %s (nas %s",
                           grad_request_code_to_name(reply_code), 
                           radreq->id,
 			  grad_ip_iptostr(radreq->ipaddr, NULL),
-                          grad_nas_request_to_name(radreq, buf, sizeof buf)));
+                          grad_nas_request_to_name(radreq, buf, sizeof buf));
                 
                 sendto(fd, pdu, length, 0,
                        &saremote, sizeof(struct sockaddr_in));
@@ -125,9 +125,9 @@ grad_server_send_challenge(int fd, grad_request_t *radreq,
 			 radreq->id, grad_ip_iptostr(radreq->ipaddr, NULL),
 			 grad_nas_request_to_name(radreq, buf, sizeof buf)));
 #else
-                debug(1, ("Sending Challenge of id %d to %s (nas %s)",
+                GRAD_DEBUG3(1, "Sending Challenge of id %d to %s (nas %s)",
                           radreq->id, grad_ip_iptostr(radreq->ipaddr, NULL),
-                          grad_nas_request_to_name(radreq, buf, sizeof buf)));
+                          grad_nas_request_to_name(radreq, buf, sizeof buf));
         
                 sendto(fd, pdu, length, 0,
                        &saremote, sizeof(struct sockaddr_in));
