@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -36,7 +36,7 @@
 #include <netinet/in.h>
 #include <net/if.h>
 
-#include <common.h>
+#include <radlib.h>
 
 #if defined(O_NONBLOCK)
 # define FCNTL_NONBLOCK O_NONBLOCK
