@@ -1,5 +1,6 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -67,9 +68,9 @@ radzap(grad_uint32_t nasaddr, int port, char *user, time_t t)
         if (t == 0) time(&t);
         netaddr = htonl(nasaddr);
 
-        if (file = rut_setent(radutmp_path, 0)) {
+        if (file = grad_ut_setent(grad_utmp_file, 0)) {
                 /* Find the entry for this NAS / portno combination. */
-                while (up = rut_getent(file)) {
+                while (up = grad_ut_getent(file)) {
                         if (((nasaddr != 0 && netaddr != up->nas_address) ||
                              (port >= 0   && port    != up->nas_port) ||
                              (user != NULL && strcmp(up->login, user) != 0) ||
@@ -78,11 +79,11 @@ radzap(grad_uint32_t nasaddr, int port, char *user, time_t t)
                         /* Zap the entry */
                         up->type = P_IDLE;
                         up->time = t;
-                        rut_putent(file, up);
+                        grad_ut_putent(file, up);
                         /* Add a logout entry to the wtmp file. */
                         write_wtmp(up);
                 }
-                rut_endent(file);
+                grad_ut_endent(file);
         }
 
         return 0;
@@ -101,7 +102,7 @@ store_session_id(char *buffer, int len, char *id, int idlen)
 int
 write_wtmp(struct radutmp *ut)
 {
-        return radwtmp_putent(radwtmp_path, ut);
+        return grad_radwtmp_putent(grad_wtmp_file, ut);
 }
 
 void
@@ -321,15 +322,15 @@ rad_acct_system(radiusd_request_t *radreq, int dowtmp)
                 return 0;
         } else if (status == DV_ACCT_STATUS_TYPE_START ||
                    status == DV_ACCT_STATUS_TYPE_STOP) {
-                debug(1,
-                    ("%s: User %s at NAS %s port %d session %-*.*s",
+                GRAD_DEBUG7(1,
+                    "%s: User %s at NAS %s port %d session %-*.*s",
                      status == DV_ACCT_STATUS_TYPE_START ? "start" : "stop",
                      ut.login,
                      grad_nas_ip_to_name(nas_address, buf, sizeof buf),
                      ut.nas_port,
                      sizeof(ut.session_id),
                      sizeof(ut.session_id),
-                     ut.session_id));
+                     ut.session_id);
         }
 
         /* Decide if we should store this record into radutmp/radwtmp.
@@ -344,16 +345,14 @@ rad_acct_system(radiusd_request_t *radreq, int dowtmp)
                 return 0;
 
         if (!ACCT_TYPE(radreq->request->avlist, DV_ACCT_TYPE_SYSTEM)) {
-                debug(1,("Acct type system disabled for %s", ut.login));
+                GRAD_DEBUG1(1,"Acct type system disabled for %s", ut.login);
                 return 0;
         }
         
         /* Update radutmp file. */
-        rc = radutmp_putent(radutmp_path, &ut, status);
-        debug(1, ("radutmp_putent=%d for %s/%s",
-                  rc,
-                  ut.login,
-                  ut.session_id));
+        rc = grad_utmp_putent(grad_utmp_file, &ut, status);
+        GRAD_DEBUG3(1, "grad_utmp_putent=%d for %s/%s",
+                    rc, ut.login, ut.session_id);
 
         /* Don't write wtmp if we don't have a username, or
            if this is an update record and the original record
@@ -384,15 +383,15 @@ disable_system_acct()
 	struct radutmp *up;
 	int written = 0;
 		
-        if ((file = rut_setent(radutmp_path, 0)) == NULL)
+        if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return;
 
-        while (up = rut_getent(file)) {
+        while (up = grad_ut_getent(file)) {
                 switch (up->type) {
 		case P_LOGIN:
                         up->type = P_IDLE;
                         time(&up->time);
-                        rut_putent(file, up);
+                        grad_ut_putent(file, up);
                         /* Add a logout entry to the wtmp file. */
                         write_wtmp(up);
 			break;
@@ -400,7 +399,7 @@ disable_system_acct()
 		case P_ACCT_ENABLED:
 			time(&up->time);
 			up->type = P_ACCT_DISABLED;
-			rut_putent(file, up);
+			grad_ut_putent(file, up);
 			write_wtmp(up);
 			written = 1;
 			break;
@@ -417,9 +416,9 @@ disable_system_acct()
 		memset(&ut, 0, sizeof ut);
 		time(&ut.time);
 		ut.type = P_ACCT_DISABLED;
-		rut_putent(file, &ut);
+		grad_ut_putent(file, &ut);
 	}
-	rut_endent(file);
+	grad_ut_endent(file);
 	grad_log(L_INFO, _("System accounting is disabled"));
 }
 
@@ -429,19 +428,19 @@ enable_system_acct()
         radut_file_t file;
 	struct radutmp *up, ut;
 		
-        if ((file = rut_setent(radutmp_path, 0)) == NULL)
+        if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return;
 
-        while (up = rut_getent(file)) {
+        while (up = grad_ut_getent(file)) {
                 if (up->type == P_ACCT_DISABLED) {
                         up->type = P_ACCT_ENABLED;
                         time(&up->time);
-                        rut_putent(file, up);
+                        grad_ut_putent(file, up);
                         /* Add an entry to the wtmp file. */
                         write_wtmp(up);
                 }
 	}
-	rut_endent(file);
+	grad_ut_endent(file);
 }
 
 void
@@ -498,23 +497,23 @@ check_acct_dir()
 {
         struct stat st;
 
-	if (stat(radacct_dir, &st) == 0) {
+	if (stat(grad_acct_dir, &st) == 0) {
 		if (S_ISDIR(st.st_mode)) {
-			if (access(radacct_dir, W_OK)) {
+			if (access(grad_acct_dir, W_OK)) {
 				grad_log(L_ERR,
 					 _("%s: directory not writable"),
-					 radacct_dir);
+					 grad_acct_dir);
 				return 1;
 			}
 			return 0;
 		} else {
 			grad_log(L_ERR, _("%s: not a directory"),
-				 radacct_dir);
+				 grad_acct_dir);
 			return 1;
 		}
 	}
 
-	if (mkdir_path(radacct_dir, 0755)) 
+	if (mkdir_path(grad_acct_dir, 0755)) 
                 return 1;
         return 0;
 }
@@ -586,18 +585,17 @@ make_detail_filename(radiusd_request_t *req, char *template,
 	if (!template) {
 		return make_legacy_detail_filename(req, default_filename);
 	} else if (template[0] == '=') {
-		Datatype type;
-		Datum datum;
-
+		grad_value_t val;
 		/*FIXME: Should be compiled!*/
-		if (rewrite_interpret(template+1, req->request, &type, &datum)) 
+		if (rewrite_interpret(template+1, req->request, &val)) 
 			return NULL;
-		if (type != String) {
+		if (val.type != String) {
 			grad_log(L_ERR, "%s: %s",
 			         template+1, _("wrong return type"));
+			/* Nothing to free in val */
 			return NULL;
 		}
-		return datum.sval;
+		return val.datum.sval.data;
 	} else {
 		struct obstack stk;
 		char *ptr;
@@ -662,7 +660,7 @@ write_detail(radiusd_request_t *radreq, int authtype, int rtype)
 		return 1;
 
 	/* Change to the accounting directory */
-	if (chdir(radacct_dir)) {
+	if (chdir(grad_acct_dir)) {
 		grad_free(filename);
 		return 1;
 	}
@@ -760,7 +758,8 @@ int
 rad_acct_ext(radiusd_request_t *radreq)
 {
         grad_avp_t *p;
-
+	int rc = 0;
+	
 #ifdef USE_SERVER_GUILE
         for (p = grad_avl_find(radreq->request->avlist, DA_SCHEME_ACCT_PROCEDURE);
 	     p;
@@ -770,15 +769,17 @@ rad_acct_ext(radiusd_request_t *radreq)
         for (p = grad_avl_find(radreq->request->avlist, DA_ACCT_EXT_PROGRAM);
 	     p;
 	     p = grad_avl_find(p->next, DA_ACCT_EXT_PROGRAM)) {
+		radius_eval_avp(radreq, p, NULL, 1);
     		switch (p->avp_strvalue[0]) {
 		case '/':
-                	radius_exec_program(p->avp_strvalue, radreq, NULL, 0);
+                	rc = radius_exec_program(p->avp_strvalue, radreq, NULL,
+						 1);
 			break;
 		case '|':
                 	filter_acct(p->avp_strvalue+1, radreq);
                 }
         }
-        return 0;
+        return rc;
 }
 
 /* run accounting modules */
@@ -838,10 +839,10 @@ radutmp_mlc_collect_user(char *name, radiusd_request_t *request,
         radut_file_t file;
 	struct radutmp *up;
 		
-        if ((file = rut_setent(radutmp_path, 0)) == NULL)
+        if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return 1;
 
-        while (up = rut_getent(file)) {
+        while (up = grad_ut_getent(file)) {
                 if (strncmp(name, up->login, RUT_NAMESIZE) == 0 &&
                     up->type == P_LOGIN) {
 			struct radutmp *tmp;
@@ -853,7 +854,7 @@ radutmp_mlc_collect_user(char *name, radiusd_request_t *request,
 			grad_list_append(*sess_list, tmp);
                 }
 	}
-	rut_endent(file);
+	grad_ut_endent(file);
 	return 0;
 }
 
@@ -863,10 +864,10 @@ radutmp_mlc_collect_realm(radiusd_request_t *request, grad_list_t **sess_list)
         radut_file_t file;
 	struct radutmp *up;
 		
-        if ((file = rut_setent(radutmp_path, 0)) == NULL)
+        if ((file = grad_ut_setent(grad_utmp_file, 0)) == NULL)
                 return 1;
 
-        while (up = rut_getent(file)) {
+        while (up = grad_ut_getent(file)) {
                 if (up->type == P_LOGIN
 		    && grad_realm_verify_ip(request->realm, up->realm_address)) {
 			struct radutmp *tmp;
@@ -878,7 +879,7 @@ radutmp_mlc_collect_realm(radiusd_request_t *request, grad_list_t **sess_list)
 			grad_list_append(*sess_list, tmp);
                 }
 	}
-	rut_endent(file);
+	grad_ut_endent(file);
 	return 0;
 }
 
@@ -887,7 +888,7 @@ radutmp_mlc_close(struct radutmp *up)
 {
 	up->type = P_IDLE;
 	up->time = time(NULL);
-	radutmp_putent(radutmp_path, up, DV_ACCT_STATUS_TYPE_STOP);
+	grad_utmp_putent(grad_utmp_file, up, DV_ACCT_STATUS_TYPE_STOP);
 }
 
 int
