@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius
    Copyright (C) 2000,2001,2002,2003,2004,
-   2006 Free Software Foundation, Inc.
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
@@ -597,14 +597,13 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         /* Process any prefixes/suffixes. */
         strip_username(1, m->namepair->avp_strvalue, m->user_check, name);
 
-        GRAD_DEBUG(1,
-	      ("auth_type=%d, userpass=%s, name=%s, password=%s",
-	       auth_type, m->userpass, name,
-	       real_password ? real_password : "NONE"));
+        GRAD_DEBUG4(1, "auth_type=%d, userpass=%s, name=%s, password=%s",
+	            auth_type, m->userpass, name,
+	            real_password ? real_password : "NONE");
 
         switch (auth_type) {
         case DV_AUTH_TYPE_SYSTEM:
-                GRAD_DEBUG(1, ("  auth: System"));
+                GRAD_DEBUG(1, "auth: System");
                 if (unix_pass(name, m->userpass) != 0)
                         result = auth_fail;
 		else
@@ -613,7 +612,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 		
         case DV_AUTH_TYPE_PAM:
 #ifdef USE_PAM
-                GRAD_DEBUG(1, ("  auth: Pam"));
+                GRAD_DEBUG(1, "auth: Pam");
                 /* Provide defaults for authdata */
                 if (authdata == NULL &&
                     (tmp = grad_avl_find(m->user_check, DA_PAM_AUTH)) != NULL) {
@@ -630,7 +629,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                 break;
 
         case DV_AUTH_TYPE_CRYPT_LOCAL:
-                GRAD_DEBUG(1, ("  auth: Crypt"));
+                GRAD_DEBUG(1, "auth: Crypt");
                 if (real_password == NULL) {
                         result = auth_fail;
                         break;
@@ -641,12 +640,12 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                         result = auth_fail;
                 else if (strcmp(real_password, pwbuf) != 0)
                         result = auth_fail;
-                GRAD_DEBUG(1,("pwbuf: %s", pwbuf));
+                GRAD_DEBUG1(1, "pwbuf: %s", pwbuf);
                 grad_free(pwbuf);
                 break;
                 
         case DV_AUTH_TYPE_LOCAL:
-                GRAD_DEBUG(1, ("  auth: Local"));
+                GRAD_DEBUG(1, "auth: Local");
                 /* Local password is just plain text. */
                 if (auth_item->attribute != DA_CHAP_PASSWORD) {
                         if (real_password == NULL ||
@@ -759,7 +758,7 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
 
         m.namepair = grad_avl_find(m.req->request->avlist, DA_USER_NAME);
 
-        GRAD_DEBUG(1, ("auth: %s", m.namepair->avp_strvalue)); 
+        GRAD_DEBUG1(1, "auth: %s", m.namepair->avp_strvalue); 
         m.state = as_init;
 
         while (m.state != as_stop) {
@@ -806,7 +805,7 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
 
 #if RADIUS_DEBUG
 # define newstate(s) do {\
-             GRAD_DEBUG(2, ("%d -> %d", m->state, s));\
+             GRAD_DEBUG2(2, "%d -> %d", m->state, s);\
              m->state = s;\
   } while (0)
 #else
@@ -1122,11 +1121,11 @@ sfn_time(AUTH_MACH *m)
                  * User is allowed, but set Session-Timeout.
                  */
                 grad_uint32_t to = set_session_timeout(m, rest);
-                GRAD_DEBUG(2, ("user %s, span %s, timeout %d, real timeout %d",
-                          m->namepair->avp_strvalue,
-                          m->check_pair->avp_strvalue,
-                          rest,
-			  to));
+                GRAD_DEBUG4(2, "user %s, span %s, timeout %d, real timeout %d",
+                            m->namepair->avp_strvalue,
+                            m->check_pair->avp_strvalue,
+                            rest,
+			    to);
         }
 }
 
@@ -1222,9 +1221,8 @@ sfn_menu_challenge(AUTH_MACH *m)
         radius_send_challenge(m->req, msg, state_value, m->activefd);
         grad_free(msg);
 	
-        GRAD_DEBUG(1,
-              ("sending challenge (menu %s) to %s",
-               m->check_pair->avp_strvalue, m->namepair->avp_strvalue));
+        GRAD_DEBUG2(1, "sending challenge (menu %s) to %s",
+                    m->check_pair->avp_strvalue, m->namepair->avp_strvalue);
         newstate(as_stop);
 #endif  
 }
@@ -1232,7 +1230,7 @@ sfn_menu_challenge(AUTH_MACH *m)
 void
 sfn_ack(AUTH_MACH *m)
 {
-        GRAD_DEBUG(1, ("ACK: %s", m->namepair->avp_strvalue));
+        GRAD_DEBUG1(1, "ACK: %s", m->namepair->avp_strvalue);
         
 	radius_eval_avl(m->req, m->user_reply);
 
@@ -1260,7 +1258,7 @@ sfn_reject_cleanup(AUTH_MACH *m)
 void
 sfn_reject(AUTH_MACH *m)
 {
-        GRAD_DEBUG(1, ("REJECT: %s", m->namepair->avp_strvalue));
+        GRAD_DEBUG1(1, "REJECT: %s", m->namepair->avp_strvalue);
 	radius_eval_avl(m->req, m->user_reply);
         radius_send_reply(RT_ACCESS_REJECT,
                           m->req,
