@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2002,2003,2004,2005,2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -171,7 +171,7 @@ radius_exec_command(char *cmd)
 	
         if (cmd[0] != '/') {
                 grad_log(L_ERR,
-   _("radius_exec_program(): won't execute, not an absolute pathname: %s"),
+   _("radius_exec_command(): won't execute, not an absolute pathname: %s"),
                          cmd);
                 return -1;
         }
@@ -185,11 +185,14 @@ radius_exec_command(char *cmd)
                 int argc;
                 char **argv;
 
-                argcv_get(cmd, "", NULL, &argc, &argv);
-                
-                for (n = grad_max_fd(); n >= 3; n--)
-                        close(n);
+                grad_argcv_get(cmd, "", NULL, &argc, &argv);
 
+		/* Leave open only stderr */
+                for (n = grad_max_fd(); n > 2; n--)
+                        close(n);
+		close(0);
+		close(1);
+		
                 chdir("/tmp");
 
                 if (radius_switch_to_user(&exec_user))
@@ -219,7 +222,7 @@ radius_exec_command(char *cmd)
 
         if (WIFEXITED(status)) {
                 status = WEXITSTATUS(status);
-                debug(1, ("returned: %d", status));
+                GRAD_DEBUG1(1, "returned: %d", status);
                 if (status == 2) {
                         grad_log(L_ERR,
                                  _("can't run external program `%s' "
@@ -240,10 +243,10 @@ radius_exec_command(char *cmd)
 }
 
 /* Execute a program on successful authentication.
-   Return 0 if exec_wait == 0.
-   Return the exit code of the called program if exec_wait != 0. */
+   Return the exit code of the called program if exec_wait is true,
+   return 0 otherwise.  */
 int
-radius_exec_program(char *cmd, grad_request_t *req, grad_avp_t **reply,
+radius_exec_program(char *cmd, radiusd_request_t *req, grad_avp_t **reply,
 		    int exec_wait)
 {
         int p[2];
@@ -278,22 +281,18 @@ radius_exec_program(char *cmd, grad_request_t *req, grad_avp_t **reply,
         if ((pid = fork()) == 0) {
                 int argc;
                 char **argv;
-                struct obstack s;
 
-                obstack_init(&s);
-                
-                /* child branch */
-                ptr = radius_xlate(&s, cmd, req, reply ? *reply : NULL);
+                GRAD_DEBUG1(1, "command line: %s", cmd);
 
-                debug(1, ("command line: %s", ptr));
-
-                argcv_get(ptr, "", NULL, &argc, &argv);
+                grad_argcv_get(cmd, "", NULL, &argc, &argv);
                 
                 if (exec_wait) {
                         if (close(p[0]))
-                                grad_log(L_ERR|L_PERROR, _("can't close pipe"));
-                        if (dup2(p[1], 1) != 1)
-                                grad_log(L_ERR|L_PERROR, _("can't dup stdout"));
+                                grad_log(L_ERR|L_PERROR,
+					 _("can't close pipe"));
+                        if (p[1] != 1 && dup2(p[1], 1) != 1)
+                                grad_log(L_ERR|L_PERROR,
+					 _("can't dup stdout"));
                 } else
 			close(1);
 
@@ -334,7 +333,7 @@ radius_exec_program(char *cmd, grad_request_t *req, grad_avp_t **reply,
 
         while (ptr = fgets(buffer, sizeof(buffer), fp)) {
                 line_num++;
-                debug(1, ("got `%s'", buffer));
+                GRAD_DEBUG1(1, "got `%s'", buffer);
                 if (userparse(ptr, &vp, &errp)) {
                         grad_log(L_ERR,
 			         _("<stdout of %s>:%d: %s"),
@@ -353,7 +352,7 @@ radius_exec_program(char *cmd, grad_request_t *req, grad_avp_t **reply,
 
         if (WIFEXITED(status)) {
                 status = WEXITSTATUS(status);
-                debug(1, ("returned: %d", status));
+                GRAD_DEBUG1(1, "returned: %d", status);
                 if (status == 2) {
                         grad_log(L_ERR,
                                  _("can't run external program `%s' "
@@ -391,15 +390,20 @@ radius_run_filter(int argc, char **argv, char *errfile, int *p)
 	case 0:
 		/* attach the pipes */
 
-		/* Right-end */
-		close(1);
-		dup2(rightp[1], 1);
-		close(rightp[0]); 
-
-		/* Left-end */
-		close(0);
-		dup2(leftp[0], 0);
+		/* Left-end. It is important that it be processed first,
+		   since it may contain descriptors 0 and 1 */
+		if (leftp[0] != 0) {
+			close(0);
+			dup2(leftp[0], 0);
+		}
 		close(leftp[1]);
+		
+		/* Right-end */
+		if (rightp[1] != 1) {
+			close(1);
+			dup2(rightp[1], 1);
+		}
+		close(rightp[0]); 
 
 		/* Error output */
 		i = open(errfile, O_CREAT|O_WRONLY|O_APPEND, 0644);
@@ -483,9 +487,10 @@ struct cleanup_info {
 };
 	
 static int
-filter_cleanup_proc(void *ptr, Filter *filter)
+filter_cleanup_proc(void *ptr, grad_symbol_t *sym)
 {
 	struct cleanup_info *info = ptr;
+	Filter *filter = (Filter *) sym;
 
 	if (filter->pid == info->pid) {
 		static char buffer[512];
@@ -502,6 +507,7 @@ filter_cleanup_proc(void *ptr, Filter *filter)
 	return 0;
 }
 
+/* Note: signal-safe */
 void
 filter_cleanup(pid_t pid, int status)
 {	
@@ -540,11 +546,11 @@ filter_kill(Filter *filter)
 }
 
 static Filter *
-filter_open(char *name, grad_request_t *req, int type, int *errp)
+filter_open(char *name, radiusd_request_t *req, int type, int *errp)
 {
 	Filter *filter = grad_sym_lookup(filter_tab, name);
 	if (!filter) {
-		grad_log_req(L_ERR, req,
+		grad_log_req(L_ERR, req->request,
 			     _("filter %s is not declared"),
 			     name);
 		*errp = -1;
@@ -561,7 +567,7 @@ filter_open(char *name, grad_request_t *req, int type, int *errp)
 						pipe);
 		
 		if (filter->pid <= 0) {
-			grad_log_req(L_ERR|L_PERROR, req,
+			grad_log_req(L_ERR|L_PERROR, req->request,
 				     _("cannot run filter %s"),
 				     name);
 			filter = NULL;
@@ -579,7 +585,8 @@ filter_open(char *name, grad_request_t *req, int type, int *errp)
 	}
 
 	if (filter && kill(filter->pid, 0)) {
-		grad_log_req(L_ERR|L_PERROR, req, _("filter %s"), name);
+		grad_log_req(L_ERR|L_PERROR, req->request,
+			     _("filter %s"), name);
 		filter_close(filter);
 		filter = NULL;
 	}
@@ -588,13 +595,13 @@ filter_open(char *name, grad_request_t *req, int type, int *errp)
 }
 
 char *
-filter_xlate(struct obstack *sp, char *fmt, grad_request_t *radreq)
+filter_xlate(struct obstack *sp, char *fmt, radiusd_request_t *radreq)
 {
-	return util_xlate(sp, fmt, radreq);
+	return util_xlate(sp, fmt, radreq->request);
 }
 
 static int
-filter_write(Filter *filter, char *fmt, grad_request_t *radreq)
+filter_write(Filter *filter, char *fmt, radiusd_request_t *radreq)
 {
 	int rc, length;
 	struct obstack stack;
@@ -610,7 +617,7 @@ filter_write(Filter *filter, char *fmt, grad_request_t *radreq)
 	} else {
 		char nl = '\n';
 		length = strlen(str);
-		debug(1,("%s < \"%s\"", filter->name, str));
+		GRAD_DEBUG2(1, "%s < \"%s\"", filter->name, str);
 		rc = write(filter->output, str, length);
 		if (rc == length) {
 			if (write(filter->output, &nl, 1) == 1)
@@ -659,7 +666,7 @@ filter_read(Filter *filter, int type, char *buffer, size_t buflen)
    Returns: 0   -- Authentication succeeded
             !0  -- Authentication failed */
 int
-filter_auth(char *name, grad_request_t *req, grad_avp_t **reply_pairs)
+filter_auth(char *name, radiusd_request_t *req, grad_avp_t **reply_pairs)
 {
 	Filter *filter;
 	int rc = -1;
@@ -691,7 +698,7 @@ filter_auth(char *name, grad_request_t *req, grad_avp_t **reply_pairs)
 			grad_avp_t *vp = NULL;
 			char *errp;
 
-			debug(1, ("%s > \"%s\"", filter->name, buffer));
+			GRAD_DEBUG2(1, "%s > \"%s\"", filter->name, buffer);
 			rc = strtoul(buffer, &ptr, 0);
 			if (userparse(ptr, &vp, &errp)) {
 				grad_log(L_ERR,
@@ -714,7 +721,7 @@ filter_auth(char *name, grad_request_t *req, grad_avp_t **reply_pairs)
 }
 
 int
-filter_acct(char *name, grad_request_t *req)
+filter_acct(char *name, radiusd_request_t *req)
 {
 	Filter *filter;
 	int rc = -1;
@@ -744,7 +751,7 @@ filter_acct(char *name, grad_request_t *req)
 		} else if (isdigit(buffer[0])) {
 			char *ptr;
 
-			debug(1, ("%s > \"%s\"", filter->name, buffer));
+			GRAD_DEBUG2(1, "%s > \"%s\"", filter->name, buffer);
 			rc = strtoul(buffer, &ptr, 0);
 			if (!isspace(*ptr)) {
 				grad_log(L_ERR,
@@ -773,7 +780,7 @@ free_symbol_entry(Filter *filter)
 {
 	grad_free(filter->descr[R_AUTH].input_fmt);
 	grad_free(filter->descr[R_ACCT].input_fmt);
-	argcv_free(filter->argc, filter->argv);
+	grad_argcv_free(filter->argc, filter->argv);
 	grad_free(filter->errfile);
 	if (filter->pid > 0)
 		filter_close(filter);
@@ -866,9 +873,9 @@ exec_path_handler(int argc, cfg_value_t *argv,
 		return 0;
 	}
 	
-	if (argcv_get(argv[1].v.string, "", NULL,
+	if (grad_argcv_get(argv[1].v.string, "", NULL,
 		      &filter_symbol.argc, &filter_symbol.argv)) {
-		argcv_free(filter_symbol.argc, filter_symbol.argv);
+		grad_argcv_free(filter_symbol.argc, filter_symbol.argv);
 		filter_symbol.argc = 0;
 	}
 	return 0;
@@ -893,7 +900,7 @@ error_log_handler(int argc, cfg_value_t *argv,
 	else if (argv[1].v.string[0] == '/')
 		filter_symbol.errfile = argv[1].v.string;
 	else {
-		char *p = grad_mkfilename(radlog_dir, argv[1].v.string);
+		char *p = grad_mkfilename(grad_log_dir, argv[1].v.string);
 		filter_symbol.errfile = cfg_malloc(strlen(p)+1, NULL);
 		strcpy(filter_symbol.errfile, p);
 		grad_free(p);
