@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006 Free Software Foundation, Inc.
+   2006, 2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -322,20 +322,20 @@ user_find_sym(char *name, radiusd_request_t *req,
         User_symbol *sym;
         USER_LOOKUP lu;
         
-        GRAD_DEBUG(1,("looking for %s", name));
+        GRAD_DEBUG1(1,"looking for %s", name);
         for (sym = user_lookup(name, &lu); sym; sym = user_next(&lu)) {
                 if (match_user(sym, req, check_pairs, reply_pairs)) {
 			if (lu.state != LU_begin)
 				found = 1;
                         if (!fallthrough(sym->reply))
                                 break;
-                        GRAD_DEBUG(1, ("fall through"));
+                        GRAD_DEBUG(1, "fall through");
                         lu.sym = NULL; /* force jump to next state */
                 }
         }
 	if (found)
 		radiusd_sql_reply_attr_query(req, reply_pairs);
-        GRAD_DEBUG(1, ("returning %d", found));
+        GRAD_DEBUG1(1, "returning %d", found);
         return found;
 }
 
@@ -366,7 +366,7 @@ match_user(User_symbol *sym, radiusd_request_t *req,
                 for (p = grad_avl_find(sym->check, DA_MATCH_PROFILE);
                      p; 
                      p = grad_avl_find(p->next, DA_MATCH_PROFILE)) {
-                        GRAD_DEBUG(1, ("submatch: %s", p->avp_strvalue));
+                        GRAD_DEBUG1(1, "submatch: %s", p->avp_strvalue);
 
                         found = match_user(grad_sym_lookup(user_tab,
 							   p->avp_strvalue),
@@ -388,14 +388,14 @@ match_user(User_symbol *sym, radiusd_request_t *req,
                 for (p = grad_avl_find(sym->reply, DA_MATCH_PROFILE);
                      p;
                      p = grad_avl_find(p->next, DA_MATCH_PROFILE)) {
-                        GRAD_DEBUG(1, ("next: %s", p->avp_strvalue));
+                        GRAD_DEBUG1(1, "next: %s", p->avp_strvalue);
                         match_user(grad_sym_lookup(user_tab, p->avp_strvalue),
                                    req, check_pairs, reply_pairs);
                 }
                 if (!fallthrough(sym->reply))
                         break;
-                GRAD_DEBUG(1, ("fall through near %s:%lu",
-			  sym->loc.file, (unsigned long) sym->loc.line));
+                GRAD_DEBUG2(1, "fall through near %s:%lu",
+			    sym->loc.file, (unsigned long) sym->loc.line);
         } while (sym = grad_sym_next((grad_symbol_t*)sym));
 
         return found;
@@ -738,7 +738,7 @@ hints_setup(radiusd_request_t *req)
 						      name_pair->avp_strvalue);
         }
 
-        GRAD_DEBUG(1, ("called for `%s'", name_pair->avp_strvalue));
+        GRAD_DEBUG1(1, "called for `%s'", name_pair->avp_strvalue);
         
         /* if Framed-Protocol is present but Service-Type is missing, add
            Service-Type = Framed-User. */
@@ -761,8 +761,9 @@ hints_setup(radiusd_request_t *req)
                 matched++;
                 radius_req_register_locus(req, &rule->loc);
 		
-                GRAD_DEBUG(1, ("matched %s at %s:%lu", rule->name, rule->loc.file,
-			  (unsigned long) rule->loc.line));
+                GRAD_DEBUG3(1, "matched %s at %s:%lu", 
+                            rule->name, rule->loc.file,
+			    (unsigned long) rule->loc.line);
         
                 add = grad_avl_dup(rule->rhs);
         
@@ -801,7 +802,7 @@ hints_setup(radiusd_request_t *req)
 		tmp = grad_avl_find(req->request->avlist, DA_USER_NAME);
 		if (tmp)
 			name_pair = tmp;
-                GRAD_DEBUG(1, ("new name is `%s'", name_pair->avp_strvalue));
+                GRAD_DEBUG1(1, "new name is `%s'", name_pair->avp_strvalue);
 
                 /* fix-up the string length. FIXME: Do we still need it? */
                 name_pair->avp_strlength = strlen(name_pair->avp_strvalue);
@@ -860,9 +861,9 @@ huntgroup_match(radiusd_request_t *req, char *huntgroup)
                 if (strcmp(rule->name, huntgroup) != 0)
                         continue;
                 if (paircmp(req, rule->lhs, NULL) == 0) {
-                        GRAD_DEBUG(1, ("matched %s at %s:%lu",
-				  rule->name, rule->loc.file,
-				  (unsigned long) rule->loc.line));
+                        GRAD_DEBUG3(1, "matched %s at %s:%lu",
+				    rule->name, rule->loc.file,
+				    (unsigned long) rule->loc.line);
                         break;
                 }
         }
@@ -895,8 +896,8 @@ huntgroup_access(radiusd_request_t *radreq, grad_locus_t *loc)
                  */
                 if (paircmp(radreq, rule->lhs, NULL) != 0)
                         continue;
-                GRAD_DEBUG(1, ("matched huntgroup at %s:%lu", rule->loc.file,
-			  (unsigned long) rule->loc.line));
+                GRAD_DEBUG2(1, "matched huntgroup at %s:%lu", rule->loc.file,
+			    (unsigned long) rule->loc.line);
                 r = paircmp(radreq, rule->rhs, NULL) == 0;
                 break;
         }
@@ -908,7 +909,7 @@ huntgroup_access(radiusd_request_t *radreq, grad_locus_t *loc)
 		radius_req_register_locus(radreq, &rule->loc);
 		rule_eval_rewrite (radreq, rule);
 	}
-        GRAD_DEBUG(1, ("returning %d", r));
+        GRAD_DEBUG1(1, "returning %d", r);
         return r;
 }
 
@@ -990,12 +991,12 @@ client_lookup_ip(grad_uint32_t ipaddr)
 			char ipbuf[GRAD_IPV4_STRING_LENGTH];
 			char maskbuf[GRAD_IPV4_STRING_LENGTH];
 
-			GRAD_DEBUG(10,
-			      ("Found secret for %s/%s (%s): %s",
-			       grad_ip_iptostr(cl->netdef.ipaddr, ipbuf),
-			       grad_ip_iptostr(cl->netdef.netmask, maskbuf),
-			       cl->longname,
-			       cl->secret));  
+			GRAD_DEBUG4(10,
+			           "Found secret for %s/%s (%s): %s",
+			           grad_ip_iptostr(cl->netdef.ipaddr, ipbuf),
+			           grad_ip_iptostr(cl->netdef.netmask, maskbuf),
+			           cl->longname,
+			           cl->secret);  
 			break;
 		}
 	
@@ -1277,8 +1278,8 @@ presufcmp(grad_avp_t *check, char *name, char *rest)
         int len, namelen;
         int ret = -1;
 
-        GRAD_DEBUG(1, ("comparing %s and %s, check->attr is %d",
-                 name, check->avp_strvalue, check->attribute));
+        GRAD_DEBUG3(1, "comparing %s and %s, check->attr is %d",
+                    name, check->avp_strvalue, check->attribute);
 
         len = strlen(check->avp_strvalue);
         switch (check->attribute) {
@@ -1298,7 +1299,7 @@ presufcmp(grad_avp_t *check, char *name, char *rest)
                         }
                         break;
         }
-        GRAD_DEBUG(1, ("returning %d", ret));
+        GRAD_DEBUG1(1, "returning %d", ret);
         return ret;
 }
 
@@ -1379,7 +1380,7 @@ paircmp(radiusd_request_t *request, grad_avp_t *check, char *pusername)
                  */
                 for (auth_item = request->request->avlist; auth_item; 
                                 auth_item = auth_item->next) {
-                        GRAD_DEBUG(30, ("trying %d", auth_item->attribute));
+                        GRAD_DEBUG1(30, "trying %d", auth_item->attribute);
 
                         switch (check_item->attribute) {
                         case DA_PREFIX:
@@ -1477,7 +1478,7 @@ paircmp(radiusd_request_t *request, grad_avp_t *check, char *pusername)
                         break;
                 }
 
-                GRAD_DEBUG(20, ("compare: %d", compare));
+                GRAD_DEBUG1(20, "compare: %d", compare);
 
                 result = comp_op(check_item->operator, compare);
 
@@ -1485,7 +1486,7 @@ paircmp(radiusd_request_t *request, grad_avp_t *check, char *pusername)
                         check_item = check_item->next;
         }
 
-        GRAD_DEBUG(20, ("returning %d", result));
+        GRAD_DEBUG1(20, "returning %d", result);
         return result;
 }
 
@@ -1507,91 +1508,82 @@ matching_rule_free(void *item, void *data ARG_UNUSED)
 }
 
 /* ***************************************************************************
- * a *very* restricted version  of wildmat
+ * an extended version of wildmat
  */
-char *
-wild_start(char *str)
-{
-        char *p;
+#define WILD_FALSE 0
+#define WILD_TRUE  1
+#define WILD_ABORT 2
 
-        p = str;
-        while (*p) {
-                switch (*p) {
-                case '*':
-                case '?':
-                        return p;
-                        
-                case '\\':
-                        if (p[1] == '(' || p[1] == ')')
-                                return p;
-                        /*FALLTHRU*/
-                default:
-                        p++;
-                }
-        }
-        return NULL;
+struct wild_match_range {
+	char *start;
+	char *end;
+};
+
+int
+match_char_class(char **pexpr, char c)
+{
+	int res;
+	int rc;
+	char *expr = *pexpr;
+	
+	expr++;
+	if (*expr == '^') {
+		res = 0;
+		expr++;
+	} else
+		res = 1;
+
+	if (*expr == '-' || *expr == ']') 
+		rc = c == *expr++;
+	else
+		rc = !res;
+	
+	for (; *expr && *expr != ']'; expr++) {
+		if (rc == res) {
+			if (*expr == '\\' && expr[1] == ']')
+				expr++;
+		} else if (expr[1] == '-') {
+			if (*expr == '\\')
+				rc = *++expr == c;
+			else {
+				rc = *expr <= c && c <= expr[2];
+				expr += 2;
+			}
+		} else if (*expr == '\\' && expr[1] == ']')
+			rc == *++expr == c;
+		else
+			rc = *expr == c;
+	}
+	*pexpr = *expr ? expr + 1 : expr;
+	return rc == res;
 }
 
 int
-match_any_chars(char **expr, char **name)
+_wild_match(char *expr, char *name, struct wild_match_range *r)
 {
-        char *exprp, *expr_start, *p, *namep;
-        int length;
-        
-        exprp = *expr;
-        while (*exprp && *exprp == '*')
-                exprp++;
-        
-        expr_start = exprp;
-        while (exprp[0] == '\\' && (exprp[1] == '(' || exprp[1] == ')'))
-                exprp += 2;
-        
-        p = wild_start(exprp);
-        
-        if (p) 
-                length = p - exprp;
-        else
-                length = strlen(exprp);
-
-        if (length == 0) {
-                *name += strlen(*name);
-        } else {
-                namep = *name + strlen(*name) - 1;
-                while (namep > *name) {
-                        if (strncmp(namep, exprp, length) == 0) {
-                                *name = namep;
-                                break;
-                        }
-                        namep--;
-                }
-        }
-        *expr = (exprp == expr_start) ? p : expr_start;
-        return 0;
-}
-
-int
-wild_match(char *expr, char *name, char *return_name)
-{
-        char *curp;
-        char *start_pos, *end_pos;
         int c;
         
-        strcpy(return_name, name);
-        start_pos = end_pos = NULL;
-        curp = name;
         while (expr && *expr) {
+		if (*name == 0 && *expr != '*')
+			return WILD_ABORT;
                 switch (*expr) {
                 case '*':
-                        expr++;
-                        if (match_any_chars(&expr, &curp))
-                                return curp - name + 1;
-                        break;
+			while (*++expr == '*')
+				;
+			if (*expr == 0)
+				return WILD_TRUE;
+			while (*name) {
+				int res = _wild_match(expr, name++, r);
+				if (res != WILD_FALSE)
+					return res;
+			}
+                        return WILD_ABORT;
                         
                 case '?':
                         expr++;
-                        if (*curp == 0)
-                                return curp - name + 1;
-                        curp++;
+                        if (*name == 0)
+                                return WILD_FALSE;
+                        name++;
                         break;
                         
                 case '\\':
@@ -1599,31 +1591,51 @@ wild_match(char *expr, char *name, char *return_name)
                                 goto def;
                         c = *++expr; expr++;
                         if (c == '(') {
-                                start_pos = curp;
+                                if (r)
+					r->start = name;
                         } else if (c == ')') {
-                                end_pos = curp;
-                                if (start_pos) {
-                                        int len = end_pos - start_pos;
-                                        strncpy(return_name, start_pos, len);
-                                        return_name += len;
-                                        *return_name = 0;
-                                }
+                                if (r)
+					r->end = name;
                         } else {
-                                if (*curp != c)
-                                        return curp - name + 1;
-                                curp++;
+                                if (*name != c)
+                                        return WILD_FALSE;
+                                name++;
                         }
                         break;
-                        
+
+		case '[':
+			if (!match_char_class(&expr, *name))
+				return WILD_FALSE;
+			name++;
+			break;
+			
+			
                 default:
                 def:
-                        if (*expr != *curp)
-                                return curp - name + 1;
+                        if (*expr != *name)
+                                return WILD_FALSE;
                         expr++;
-                        curp++;
+                        name++;
                 }
         }
-        return *curp != 0;
+        return *name == 0;
+}
+
+int
+wild_match(char *expr, char *name, char *return_name)
+{
+	int rc;
+	struct wild_match_range range;
+	range.start = range.end = NULL;
+	rc = _wild_match(expr, name, &range) == WILD_TRUE;
+	if (rc) {
+		if (range.start && range.end) {
+			int len = range.end - range.start;
+			strncpy(return_name, range.start, len);
+		} else
+			strncpy(return_name, name, GRAD_STRING_LENGTH);
+	}
+	return rc;
 }
 
 /* ************************************************************************* */
@@ -1632,12 +1644,14 @@ wild_match(char *expr, char *name, char *return_name)
  * Match a username with a wildcard expression.
  */
 int
-matches(radiusd_request_t *req, char *name, grad_matching_rule_t *pl, char *matchpart)
+matches(radiusd_request_t *req, char *name, grad_matching_rule_t *pl,
+	char *matchpart)
 {
 	memcpy(matchpart, name, GRAD_STRING_LENGTH);
-        if (strncmp(pl->name, "DEFAULT", 7) == 0
-	    || wild_match(pl->name, name, matchpart) == 0)
+	if (strncmp(pl->name, "DEFAULT", 7) == 0
+	    || wild_match(pl->name, name, matchpart)) 
                 return paircmp(req, pl->lhs, matchpart);
+
         return 1;
 }       
         
