@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006 Free Software Foundation, Inc.
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -641,18 +641,17 @@ sql_cache_destroy(struct sql_connection *conn)
 static void
 sql_cache_insert(struct sql_connection *conn, SQL_RESULT *res)
 {
-	GRAD_DEBUG(20,
-	      ("cache: %d,(%d,%d)",
-	       sql_cache_level(conn),conn->head,conn->tail));
+	GRAD_DEBUG3(20, "cache: %d,(%d,%d)",
+	            sql_cache_level(conn),conn->head,conn->tail);
 	if (sql_cache_level(conn) >= SQL_CACHE_SIZE-1) {
 		sql_result_destroy(conn->cache[conn->head]);
 		conn->head = (conn->head + 1) % SQL_CACHE_SIZE;
-	        GRAD_DEBUG(20,("head: %d,%d", conn->head,conn->tail));
+	        GRAD_DEBUG2(20,"head: %d,%d", conn->head,conn->tail);
 	}
-	GRAD_DEBUG(20,("inserting at pos %d", conn->tail));
+	GRAD_DEBUG1(20,"inserting at pos %d", conn->tail);
 	conn->cache[conn->tail] = res;
 	conn->tail = (conn->tail + 1) % SQL_CACHE_SIZE;
-	GRAD_DEBUG(20,("tail: %d,%d", conn->head,conn->tail));
+	GRAD_DEBUG2(20,"tail: %d,%d", conn->head,conn->tail);
 }
 
 static SQL_RESULT *
@@ -662,7 +661,7 @@ sql_cache_retrieve(struct sql_connection *conn, char *query)
 	SQL_RESULT *res;
 	size_t i;
 	
-	GRAD_DEBUG(20,("query: %s",query));
+	GRAD_DEBUG1(20,"query: %s",query);
 	res = grad_emalloc(sizeof(*res));
 	res->query = grad_estrdup(query);
 	res->nfields = res->ntuples = 0;
@@ -707,15 +706,15 @@ sql_cache_lookup(struct sql_connection *conn, char *query)
 {
 	size_t i;
 
-	GRAD_DEBUG(20,("looking up %s", query));
+	GRAD_DEBUG1(20,"looking up %s", query);
 	for (i = conn->head; i != conn->tail;
 	     i = (i + 1) % SQL_CACHE_SIZE) {
 		if (strcmp(conn->cache[i]->query, query) == 0) {
-			GRAD_DEBUG(20,("found at %d", i));
+			GRAD_DEBUG1(20,"found at %d", i);
 			return conn->cache[i];
 		}
 	}
-	GRAD_DEBUG(20,("NOT FOUND"));
+	GRAD_DEBUG(20,"NOT FOUND");
 	return NULL;
 }
 
@@ -731,7 +730,7 @@ attach_sql_connection(int type)
         time(&now);
         conn = sql_conn[type];
         if (!conn) {
-                GRAD_DEBUG(1, ("allocating new %d sql connection", type));
+                GRAD_DEBUG1(1, "allocating new %d sql connection", type);
 
                 conn = grad_emalloc(sizeof(struct sql_connection));
 		conn->cfg = &sql_cfg;
@@ -745,12 +744,12 @@ attach_sql_connection(int type)
         }
 
         if (!conn->connected || now - conn->last_used > sql_cfg.idle_timeout) {
-                GRAD_DEBUG(1, ("connection %d timed out: reconnect", type));
+                GRAD_DEBUG1(1, "connection %d timed out: reconnect", type);
                 disp_sql_reconnect(sql_cfg.interface, type, conn);
         }
 	conn->destroy_on_close = !sql_cfg.keepopen;
         conn->last_used = now;
-        GRAD_DEBUG(1, ("attaching %p [%d]", conn, type));
+        GRAD_DEBUG2(1, "attaching %p [%d]", conn, type);
         return conn;
 }
 
@@ -762,10 +761,9 @@ detach_sql_connection(int type)
         conn = sql_conn[type];
         if (!conn)
                 return;
-        GRAD_DEBUG(1, ("detaching %p [%d]", conn, type));
+        GRAD_DEBUG2(1, "detaching %p [%d]", conn, type);
         if (conn->destroy_on_close) {
-                GRAD_DEBUG(1, ("destructing sql connection %p",
-                          conn));
+                GRAD_DEBUG1(1, "destructing sql connection %p", conn);
 		sql_conn_destroy(&sql_conn[type]);
         }
 }
@@ -1306,6 +1304,23 @@ sql_exec_query(int type, char *query)
 	
 	return row_head;
 }
+
+SCM
+sql_run_query(int type, char *query)
+{
+	int rc;
+        struct sql_connection *conn;
+	int count;
+	SCM res;
+	
+	if (type < 0 || type > SQL_NSERVICE)
+		return SCM_BOOL_F;
+	conn = attach_sql_connection(type);
+	rc = disp_sql_query(conn, query, &count);
+	if (rc)
+                return SCM_BOOL_F;
+	return scm_long2num(count);
+}
 #endif
 
 #else
